import React from "react";
import { BrowserRouter as Router, Route, Link } from "react-router-dom";

//import material ui
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import Divider from '@material-ui/core/Divider';
import HomeIcon from '@material-ui/icons/Home';
import CloudIcon from '@material-ui/icons/Cloud';
import WallpaperIcon from '@material-ui/icons/Wallpaper';
import LanguageIcon from '@material-ui/icons/Language';
import LogoutIcon from "@material-ui/icons/ExitToApp";

//import containers
import LandingPageContainer from "../containers/landingPageContainer/LandingPageContainer";
import SampleClientContainer from "../containers/sampleClientContainer/sampleClientContainer";
import CleanContainer from "../containers/cleanContainer/cleanContainer";

//import components
import FrameComponent from "../components/FrameComponent";

//import login
import LoginDialog from "../login/components/LoginDialog";

import Auth0LoginButton from "../login/auth0/LoginButtonComponent";
import Auth0LoginProvider from "../login/auth0/LoginProviderComponent";

import MicrosoftLoginButton from "../login/microsoft/LoginButtonComponent";
import MicrosoftLoginProvider from "../login/microsoft/LoginProviderComponent";

import UserCard from "../login/components/UserCardComponent";

class MainContainer extends React.Component {
    constructor() {
        super();
        this.state = {
            user: [],
            provider: undefined
        }
    }

    login = (user, provider) => {
        this.setState({
            user: user,
            provider: provider
        });
    }

    logout = () => {
        this.setState({
            user: [],
            provider: undefined
        });
    }

    render() {

        const Profile = () => {
            switch (this.state.provider) {
                case undefined:
                    return null
                case "auth0":
                    return (
                        <UserCard
                            first = {this.state.user.given_name}
                            last = {this.state.user.family_name}
                            picture = {this.state.user.picture}
                        />
                    );
                case "microsoft":
                    return (
                        <UserCard
                            first = {this.state.user.givenName}
                            last = {this.state.user.surname}
                            picture = {false}
                        />
                    );
                default:
                    return null
            }
        }

        const Login = () => {
            if (this.state.provider === undefined) {
                return (
                    <LoginDialog
                        auth0Login={
                            <Auth0LoginButton />}
                        microsoftLogin={
                            <MicrosoftLoginButton
                                login={this.login}
                            />
                        }
                    />
                );
            }
            else {
                return (
                    <ListItem button onClick={this.logout}>
                        <ListItemIcon>
                            <LogoutIcon />
                        </ListItemIcon>
                        <ListItemText primary="Logout" />
                    </ListItem>
                );
            }
        }

        const Menu = () => {
            return (
                <React.Fragment>
                    <List>
                        <Link className={"Menu-router-link"} to="/">
                            <ListItem button>
                                <ListItemIcon>
                                    <HomeIcon />
                                </ListItemIcon>
                                <ListItemText primary="Home" />
                            </ListItem>
                        </Link>

                        <Link className={"Menu-router-link"} to="/sampleClient">
                            <ListItem button>
                                <ListItemIcon>
                                    <CloudIcon />
                                </ListItemIcon>
                                <ListItemText primary="Sample client" />
                            </ListItem>
                        </Link>

                        <Link className={"Menu-router-link"} to="/clean">
                            <ListItem button>
                                <ListItemIcon>
                                    <WallpaperIcon />
                                </ListItemIcon>
                                <ListItemText primary="Clean container" />
                            </ListItem>
                        </Link>

                        <Divider />

                        {Login()}

                        <ListItem button>
                            <ListItemIcon>
                                <LanguageIcon />
                            </ListItemIcon>
                            <ListItemText primary="Language" />
                        </ListItem>

                    </List>
                </React.Fragment>
            );
        }

        return (
            <React.Fragment>
                <MicrosoftLoginProvider
                    login={this.login}
                />
                <Auth0LoginProvider
                    login={this.login}
                />
                <Router>
                    <FrameComponent
                        tab={
                            <React.Fragment>
                                <Route path="/" exact component={LandingPageContainer} />
                                <Route path="/sampleClient/" component={SampleClientContainer} />
                                <Route path="/clean/" component={CleanContainer} />
                            </React.Fragment>
                        }
                        menu={Menu()}
                        user={Profile()}
                    />
                </Router>
            </React.Fragment>
        );
    }
}

export default MainContainer;